==> ratis-thirdparty-misc-1.0.8-sources.jar: org/apache/ratis/thirdparty/io/grpc/InternalConfiguratorRegistry.java <==
/*
 * Copyright 2024 The gRPC Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ratis.thirdparty.io.grpc;

import java.util.List;

/**
 * Access internal global configurators.
 */
@Internal
public final class InternalConfiguratorRegistry {
  private InternalConfiguratorRegistry() {}

  public static void setConfigurators(List<InternalConfigurator> configurators) {
    ConfiguratorRegistry.getDefaultRegistry().setConfigurators(configurators);
  }

  public static List<?> getConfigurators() {
    return ConfiguratorRegistry.getDefaultRegistry().getConfigurators();
  }

  public static void configureChannelBuilder(ManagedChannelBuilder<?> channelBuilder) {
    for (Configurator configurator : ConfiguratorRegistry.getDefaultRegistry().getConfigurators()) {
      configurator.configureChannelBuilder(channelBuilder);
    }
  }

  public static void configureServerBuilder(ServerBuilder<?> serverBuilder) {
    for (Configurator configurator : ConfiguratorRegistry.getDefaultRegistry().getConfigurators()) {
      configurator.configureServerBuilder(serverBuilder);
    }
  }

  public static boolean wasSetConfiguratorsCalled() {
    return ConfiguratorRegistry.getDefaultRegistry().wasSetConfiguratorsCalled();
  }
}

==> ratis-thirdparty-misc-1.0.10-sources.jar: org/apache/ratis/thirdparty/io/grpc/InternalConfiguratorRegistry.java <==
/*
 * Copyright 2024 The gRPC Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ratis.thirdparty.io.grpc;

import java.util.List;

/**
 * Access internal global configurators.
 */
@Internal
public final class InternalConfiguratorRegistry {
  private InternalConfiguratorRegistry() {}

  public static void setConfigurators(List<InternalConfigurator> configurators) {
    ConfiguratorRegistry.getDefaultRegistry().setConfigurators(configurators);
  }

  public static List<?> getConfigurators() {
    return ConfiguratorRegistry.getDefaultRegistry().getConfigurators();
  }

  public static void configureChannelBuilder(ManagedChannelBuilder<?> channelBuilder) {
    for (Configurator configurator : ConfiguratorRegistry.getDefaultRegistry().getConfigurators()) {
      configurator.configureChannelBuilder(channelBuilder);
    }
  }

  public static void configureServerBuilder(ServerBuilder<?> serverBuilder) {
    for (Configurator configurator : ConfiguratorRegistry.getDefaultRegistry().getConfigurators()) {
      configurator.configureServerBuilder(serverBuilder);
    }
  }

  public static boolean wasSetConfiguratorsCalled() {
    return ConfiguratorRegistry.getDefaultRegistry().wasSetConfiguratorsCalled();
  }

  public static int getConfiguratorsCallCountBeforeSet() {
    return ConfiguratorRegistry.getDefaultRegistry().getConfiguratorsCallCountBeforeSet();
  }
}
